import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The game board. The board had a paddle that can move.
 * 
 * @author Tony Streef
 * @version 1.0 (maart 2014)
 */
public class Board extends World
{
    private String[] afbeeldingen = {"level0.jpg","level1.jpg","level2.jpg","level3.jpg","level4.jpg"};
    private int score = 0;
    private int level = 0;
    
    private Message message1 = null;
    private Message message2 = null;
    private Message message3 = null;
    private Message message4 = null;
    private Message message5 = null;
    private Message message6 = null;
    private Message message7 = null;
    private Message message8 = null;
    private Message message9 = null;
    
    private Paddle paddle; 
    private Brick brick;
    private Bonus bonus;
    private Trap trap;
    private Ball ball;
    private Life life1;
    private Life life2;
    private Life life3;     
    
    /**
     * Constructor van de klasse Board. 
     * Alles in de constructor wordt uitgevoerd zodra de wereld wordt aangemaakt.
     */
    public Board()
    {    
        super(924, 520, 1);
        setPaintOrder ( Ball.class, Smoke.class );
        
        paddle = new Paddle();
        addObject ( paddle, getWidth() / 2, getHeight() - 40);
        
        
        
        message1 = new Message("Score: " + score);
        addObject(message1, 125, 30);
        
        message2 = new Message("Level: " + level);
        addObject(message2,125, 60);
        
        message3 = new Message("Lives:");
        addObject(message3, 850, 30);
        
        message4 = new Message("Press space to jump...");
        addObject(message4, 480, 60);
                
        
        
        life1 = new Life();
        addObject(life1, 825,25);
        
        life2 = new Life();
        addObject(life2, 860,25);
        
        life3 = new Life();
        addObject(life3, 895,25);
        
              
        
        upgradeLevel();          
    }
    
    
    /**
     * De methode upgradeLevel() controleert of de score een veelvoud van 10 is.
     * Als dat het geval is wordt er een nieuw level aangemaakt.
     * Level 4 is geen echt level, maar het eindscherm.
     */
    public void upgradeLevel()
    {
        if (score%10==0)
        {
            level++;
            checkBackground();
            message2.setText("Level: " + level);
            
                if(level == 1)
                {
                    message6 = new Message("Collect all bananas!");
                    addObject(message6,480, 30); 
                    
                    addBrick();
                    Greenfoot.playSound("Ground_Rules.mp3");
                }
                if(level == 2)
                {
                    removeObject(message6);
                    message7 = new Message("Don't get too friendly!");
                    addObject(message7,480, 30); 
                    
                    
                    addBrick();
                    addBonus();
                    increaseBallSpeed();
                    
                    trap = new Trap();
                    addObject(trap,490, 100);
                    Greenfoot.playSound("Steal_the_Moon.mp3");
                }
                if(level == 3)
                {
                    removeObject(message7);
                    message8 = new Message("Seems easy...right?");
                    addObject(message8,480, 30); 
                    
                    addBrick();
                    addBonus();
                    increaseBallSpeed();
                    Greenfoot.playSound("Try_This.mp3");
                                    }
                if(level == 4)
                {
                    removeObject(message8);
                    removeMessage4();
                    paddle.removeBall();
                    removeObject(paddle);  
                    removeTraps();
                    removeBonus();
                    removeBricks();
                    
                    message9 = new Message("CONGRATULATIONS!");
                    addObject(message9,480, 30); 
                    
                    Greenfoot.playSound("Banana_song.mp3");
                }
                                        
        }
    }
    
    /**
     * De methode checkBackground() stelt de juiste achtergrond in door de titel van de achtegrond te vergelijken met het huidige level.
     * 
     */
    public void checkBackground()
    {
           this.setBackground(afbeeldingen[level%afbeeldingen.length]);
    }
    
    /**
     * De methode endScreen() geeft aan of we in level 4 zitten of niet. De methode wordt aangeroepen in de klasse Ball.
     */
    public boolean endScreen()
    {
        if(level == 4)
        {
            return true;
        }
        else 
        {
            return false;
        }
    }
    
    /**
     * De methode incrementScore() verhoogt de score met 1. 
     * Vervolgens worden de methode upgradeLevel() en addTrap() aangeroepen om te zien of deze moeten worden uitgevoerd.
     */
    public void incrementScore()
    {
        score ++;
        message1.setText("Score: " + score);
        upgradeLevel();
        addTrap();
    }
    
    /**
     * De methode ballIsOut() vertelt wat er moet gebeuren als is vastgesteld dat de Minion (ball) uit de wereld is/moet zijn. 
     */
    public void ballIsOut()
    {
        Greenfoot.playSound("Hohoho.mp3");
        if (paddle.getNumBalls() > 3)
        {
            removeObject(life3);
            removeObject(message6);
            removeObject(message7);
            removeObject(message8);
              
            message5 = new Message("GAME OVER");
            addObject(message5,510, 30);             
        }
        else
        {
            if(paddle.getNumBalls()==2)
            {
                removeObject(life1);
            }
            if(paddle.getNumBalls()==3)
            {
                removeObject(life2);
            }
            
            paddle.newBall();
            message4 = new Message("Press space to jump...");
            addObject(message4,480, 60); 
        }
               
    }
        
    /**
     * De methode addBrick() voegt 10 bananen (bricks) in op een willekeurige plek op het scherm (wel binnen bepaalde grenzen).
     */
    public void addBrick()
    {
        for(int i=0; i<10; i++) 
        {
            brick = new Brick();
            int x = Greenfoot.getRandomNumber(814)+50;
            int y = Greenfoot.getRandomNumber(250)+70;
            addObject (brick, x , y);
        }
    }
  
    /**
     * De methode addTrap() plaatst MISSCHIEN op een willekeurig moment in level 3, op een willekeurige plaats, een Evil Minion (trap).  
     */
    public void addTrap()
    {
        if (score == Greenfoot.getRandomNumber(10) + 20)
        {
            trap = new Trap();
            int x = Greenfoot.getRandomNumber(814)+50;
            int y = Greenfoot.getRandomNumber(250)+70;
            addObject (trap, x , y);
        }
    
    }
    
    /**
     * De methode addBonus() plaats op een willekeurige plek een tros bananen voor een extra leven.
     * Maar alleen als de speler nog slechts 1 leven heeft aan het begin van level 2 of 3 (zie upgradeLevel()) 
     */
    public void addBonus()
    {
        if(paddle.getNumBalls()==4)
        {
            bonus = new Bonus();
            int x = Greenfoot.getRandomNumber(814)+50;
            int y = Greenfoot.getRandomNumber(250)+70;
            addObject (bonus, x , y);
        }
    }
    
    /**
     * Als de Minion (ball) de tros bananen (bonus) raakt krijgt de speler een extra leven.
     */
    public void ballHitsBonus()
    {
          removeObject(bonus);
          paddle.reduceNumBalls();
          addObject(life2, 860, 25);
          Greenfoot.playSound("Babanana.mp3");
          
    }
    
    public void increaseBallSpeed()
    {
        ((Ball)(getObjects(Ball.class).get(0))).incrementSpeed();
    }
    
    /**
     * Deze methode verwijdert message4 ("Press space to jump...").
     * Deze wordt aangeroepen in de klasse Paddle.
     */
    public void removeMessage4()
    {
    this.removeObject(message4);
    }
    
    /**
     * De methode removeTraps() verwijdert alle Evil Minions (traps) aanwezig in de wereld.
     */
    public void removeTraps()
    {
        removeObjects(getObjects(Trap.class));
    }
    
    /**
     * De methode removeBonus() verwijdert alle trossen bananen (bonus) aanwezig in de wereld.
     */
    public void removeBonus()
    {
        removeObjects(getObjects(Bonus.class));
    }
    
    /**
     * De methode removeBricks() verwijdert alle bananen (bricks) aanwezig in de wereld.
     */
    public void removeBricks()
    {
        removeObjects(getObjects(Brick.class));
    }
}
 